==> dolphin-trinity-3.5.13.2.tar.xz: dolphin-trinity-3.5.13.2/src/urlnavigatorbutton.h <==
/***************************************************************************
 *   Copyright (C) 2006 by Peter Penz (peter.penz@gmx.at)                  *
 *   Copyright (C) 2006 by Aaron J. Seigo (<aseigo@kde.org>)               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/
#ifndef URLNAVIGATORBUTTON_H
#define URLNAVIGATORBUTTON_H

#include <tqstringlist.h>

#include <kio/global.h>

#include <urlbutton.h>

class KURL;
class URLNavigator;
class TQPainter;

namespace KIO
{
    class Job;
}

/**
 * @brief Button of the URL navigator which contains one part of an URL.
 *
 * It is possible to drop a various number of items to an URL button. In this case
 * a context menu is opened where the user must select whether he wants
 * to copy, move or link the dropped items to the URL part indicated by
 * the button.
 */
class URLNavigatorButton : public URLButton
{
    Q_OBJECT
  TQ_OBJECT

public:
    URLNavigatorButton(int index, URLNavigator* parent = 0);
    virtual ~URLNavigatorButton();
    void setIndex(int index);
    int index() const;

protected:
    virtual void drawButton(TQPainter* painter);
    virtual void enterEvent(TQEvent* event);
    virtual void leaveEvent(TQEvent* event);
    //drag
    void mousePressEvent( TQMouseEvent *event );
    void mouseMoveEvent( TQMouseEvent *event );
    //drop
    virtual void dropEvent(TQDropEvent* event);
    virtual void dragEnterEvent(TQDragEnterEvent* event);
    virtual void dragLeaveEvent(TQDragLeaveEvent* event);

private slots:
    void updateNavigatorURL();
    void startPopupDelay();
    void stopPopupDelay();
    void startListJob();
    void entriesList(KIO::Job* job, const KIO::UDSEntryList& entries);
    void listJobFinished(KIO::Job* job);

private:
    int arrowWidth() const;
    bool isTextClipped() const;
    void startDrag();

    int m_index;
    TQTimer* m_popupDelay;
    KIO::Job* m_listJob;
    TQStringList m_subdirs;
    TQPoint dragPos;
};

#endif

==> dolphin-trinity-14.0.13.tar.xz: dolphin-trinity-14.0.13/src/urlnavigatorbutton.h <==
/***************************************************************************
 *   Copyright (C) 2006 by Peter Penz (peter.penz@gmx.at)                  *
 *   Copyright (C) 2006 by Aaron J. Seigo (<aseigo@kde.org>)               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/
#ifndef URLNAVIGATORBUTTON_H
#define URLNAVIGATORBUTTON_H

#include <tqstringlist.h>

#include <tdeio/global.h>

#include <urlbutton.h>

class KURL;
class URLNavigator;
class TQPainter;

namespace TDEIO
{
    class Job;
}

/**
 * @brief Button of the URL navigator which contains one part of an URL.
 *
 * It is possible to drop a various number of items to an URL button. In this case
 * a context menu is opened where the user must select whether he wants
 * to copy, move or link the dropped items to the URL part indicated by
 * the button.
 */
class URLNavigatorButton : public URLButton
{
    Q_OBJECT
  

public:
    URLNavigatorButton(int index, URLNavigator* parent = 0);
    virtual ~URLNavigatorButton();
    void setIndex(int index);
    int index() const;

protected:
    virtual void drawButton(TQPainter* painter);
    virtual void enterEvent(TQEvent* event);
    virtual void leaveEvent(TQEvent* event);
    //drag
    void mousePressEvent( TQMouseEvent *event );
    void mouseMoveEvent( TQMouseEvent *event );
    //drop
    virtual void dropEvent(TQDropEvent* event);
    virtual void dragEnterEvent(TQDragEnterEvent* event);
    virtual void dragLeaveEvent(TQDragLeaveEvent* event);

private slots:
    void updateNavigatorURL();
    void startPopupDelay();
    void stopPopupDelay();
    void startListJob();
    void entriesList(TDEIO::Job* job, const TDEIO::UDSEntryList& entries);
    void listJobFinished(TDEIO::Job* job);

private:
    int arrowWidth() const;
    bool isTextClipped() const;
    void startDrag();

    int m_index;
    TQTimer* m_popupDelay;
    TDEIO::Job* m_listJob;
    TQStringList m_subdirs;
    TQPoint dragPos;
};

#endif
